@@ -43,7 +43,7 @@
 #' @examples
 #' 
 #' 
-#' \donttest{
+#' \dontrun{
 #' 
 #' data(readmission)
 #' 
@@ -69,6 +69,8 @@
 "plot.jointPenal" <-
   function (x, event="Both", type.plot="Hazard", conf.bands=FALSE, pos.legend="topright", cex.legend=0.7, ylim, main, color=2, median=TRUE, Xlab = "Time", Ylab = "Hazard function", ...)
   {
+    oldpar <- par(no.readonly = TRUE) 
+	  on.exit(par(oldpar))
     event.type <- charmatch(event, c("Both", "Recurrent", "Terminal"), nomatch = 0)
     if (event.type == 0) {
       stop("event must be 'Both', 'Recurrent' or 'Terminal'")
