@@ -18,7 +18,8 @@
 {
 
   
-  
+oldpar <- par(no.readonly = TRUE) 
+on.exit(par(oldpar))
 # frailtyPENAL original (NON generalise)
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 if(is.null(x$family)){
