@@ -21,6 +21,7 @@ module mod_Adaptative
     integer,intent(in)::id,jd,np
     double precision,dimension(np),intent(in)::b
     double precision,dimension(2),intent(in)::k0
+    double precision,dimension(2)::k0dd
     double precision,intent(in)::thi,thj
     
     integer::n,i,j,k,vj,ig,choix,l,nsujet_trial,dimint !vcdiag
@@ -43,7 +44,9 @@ module mod_Adaptative
     double precision,dimension(ntrials)::integrale3
     double precision,dimension(2,2):: mat_A
 
-!    !print*,'debut funcpa'
+    if(.false.) then 
+        k0dd=k0 
+    end if 
     choix=0
     ig=0
     k=0
