@@ -579,7 +579,7 @@
     cb=epsb+1.d0
     rl1=-1.d+10
     ni=0
-	ni_cur=ni
+    ni_cur=ni
     istop=0
     da=0.01d0
     dm=5.d0
@@ -789,7 +789,7 @@
         end do
         
         ni=ni+1
-		ni_cur=ni
+        ni_cur=ni
         if (ni.ge.maxiter) then
             istop=2
 !            write(6,*) 'maximum number of iteration reached'
@@ -946,12 +946,13 @@
     double precision,dimension((m*(m+3)/2)),intent(inout)::v
     double precision,dimension(m)::fcith
     integer ::i0,m1,ll,i,k,j,iun
-    double precision::fctnames,thn,th,z,vl,th2,vaux
-    external::fctnames
+    double precision::thn,th,z,vl,th2,vaux
+    double precision,external::fctnames
     logical::endDeriva
 
     endDeriva=.false.
-    fcith=0.d0
+    fcith=0.d0 
+    th=0.0d0
     select case(model)
     case(1,7)
         th=1.d-3 !joint
@@ -1039,8 +1040,8 @@
       double precision,intent(inout)::fim,step
       double precision::vlw,vlw1,vlw2,vlw3,vm,fi1,fi2,fi3
       double precision,dimension(2)::k0
-      double precision::fctnames
-      external::fctnames
+      double precision,external::fctnames
+      !external::fctnames
       integer::i
 
        vlw1=dlog(vw)
@@ -1470,10 +1471,10 @@
     double precision,dimension(m),intent(in)::b,delta
     double precision,dimension(m),intent(out)::bk
     double precision,intent(out)::fi
-    double precision::vw,fctnames,z
+    double precision::vw,z
     double precision,dimension(2)::k0
     integer::i0,i
-    external::fctnames
+    double precision,external::fctnames
 
     z=0.d0
     i0=1
@@ -1861,9 +1862,9 @@
     double precision,dimension((m*(m+3)/2)),intent(out)::v
     double precision,dimension(m)::fcith
     integer ::i0,m1,ll,i,k,j,iun
-    double precision::fctnames,thn,th,z,vl,th2,vaux
-    external::fctnames
-
+    double precision::thn,th,z,vl,th2,vaux
+    double precision,external::fctnames
+    th = 0.d0 
     select case(model)
     case(1,7)
         th=1.d-3 !joint
@@ -1934,8 +1935,8 @@
       double precision,intent(inout)::fim,step
       double precision::vlw,vlw1,vlw2,vlw3,vm,fi1,fi2,fi3
       double precision,dimension(3)::k0
-      double precision::fctnames
-      external::fctnames
+      double precision,external::fctnames
+      !external::fctnames
       integer::i
 
        vlw1=dlog(vw)
@@ -2005,10 +2006,10 @@
     double precision,dimension(m),intent(in)::b,delta
     double precision,dimension(m),intent(out)::bk
     double precision,intent(out)::fi
-    double precision::vw,fctnames,z
+    double precision::vw,z
     double precision,dimension(3)::k0
     integer::i0,i
-    external::fctnames
+    double precision,external::fctnames
 
     z=0.d0
     i0=1
@@ -2496,12 +2497,12 @@
     double precision,dimension(m),intent(inout)::vindiv
     double precision,dimension(m)::fcith
     integer ::i0,i,iun !ll,m1,k,j
-    double precision::fctnamesindiv,thn,th,z,vl,th2,vaux
-    external::fctnamesindiv
+    double precision::thn,th,z,vl,th2,vaux
+    double precision,external::fctnamesindiv
     logical::endDeriva
 
     endDeriva=.false.
-    
+    th=0.d0
     select case(model)
     case(1,7)
         th=1.d-3 !joint
