@@ -204,8 +204,8 @@
         if(rang==0)then ! on affiche que pour le processus maître
             !write(*,*)'iteration***',ni,'vrais',rl
             if(affiche_itteration==1) then
-              call dblepr("convergence parameters: ni, log-likelihood, coef (ca), log_lik (cb),grad (dd)", -1, convcrit, 5)
-              call dblepr("b: nparamfrail + betas + betat", -1, b((m-nparamfrail-nva+1):m), nparamfrail+nva)
+              !call dblepr("convergence parameters: ni, log-likelihood, coef (ca), log_lik (cb),grad (dd)", -1, convcrit, 5)
+              !call dblepr("b: nparamfrail + betas + betat", -1, b((m-nparamfrail-nva+1):m), nparamfrail+nva)
             endif
         endif
     endif
@@ -527,11 +527,12 @@
     double precision,dimension((m*(m+3)/2)),intent(out)::v
     double precision,dimension(m)::fcith
     integer ::i0,m1,ll,i,k,j,iun
-    double precision::fctnames,thn,th,z,vl,th2,vaux
-    external::fctnames
+    double precision::thn,th,z,vl,th2,vaux
+    double precision,external::fctnames
 
     ! !print*,"suis dans derivaJ, model=",model,"th=",th
     !stop
+    th=0.0d0
     select case(model)
     case(1)
         th=1.d-3 !joint
