@@ -104,13 +104,12 @@ F77_SUB(joint_longi)(const int *vectnsujet, const int *ngnzag, double *k0,
                      int *np, const int *neta0, double *b, double *h_hessout, double *hihout,
                      double *resout, double *lcv, double *x1out, double *lamout, double *xsu1,
                      double *suout, double *x2out, double *lam2out, double *xsu2, double *su2out,
-                     int *typeof0, const int *equidistant, const int *mtaille, int *counts,
-                     int *ier_istop, double *paraweib, double *martingales, double *reslongi,
-                     double *pred_y0, const int *glmlog0, const int *positionvartime,
-                     const int *numinterac, double *linearpred, double *linearpreddc,
-                     double *ziout, const int *paratps, const int *filtretps0, double *betatpsmat,
-                     double *betatpsmatdc, double *betatpsmaty, double *eps, const int *gh,
-                     const double *pagh);
+                     int *params_hazard, int *counts,int *ier_istop, double *paraweib, 
+                     double *martingales, double *reslongi,double *pred_y0, const int *glmlog0, 
+                     const int *positionvartime,const int *numinterac, double *linearpred, double *linearpreddc,
+                     double *ziout, const int *paratps, double *betamattps, double *eps, const int *gh,
+                     const double *pagh, double *med, int *varcenters, int *vartreatment,
+                     int *param_res_rt, double *res_rt);
 
 void
 F77_SUB(jointlonginl)(int *nsujet0, int *nsujety0, int *ng0, int *nz0, double *k0, double *tt00,
@@ -356,4 +355,4 @@ F77_SUB(joint_competing)(int* controls, int *nobsEvent, double *k0, double *tt00
 void F77_SUB(rndstart)(void);
 void F77_SUB(rndend)(void);
 double F77_SUB(unifrand)(void);
-void F77_SUB(updaterandomseed)(int);						
+void F77_SUB(updaterandomseed)(int *seed);						
