@@ -9,7 +9,7 @@
     im3,im2,im1,im,mm3dc,mm2dc,mm1dc,mmdc,im3dc,im2dc,im1dc,imdc,date,datedc,zi,&
     c,cdc,nt0,nt1,nt0dc,nt1dc,nsujet,nva,nva1,nva2,ndate,ndatedc,nst,&
     stra,ve,vedc,pe,effet,ng,g,nig,AG,indic_ALPHA,theta,alpha,&
-    auxig,aux1,aux2,res1,res3,indictronq,resnonpen,resL,resU,ntU
+    auxig,aux1,aux2,res1,res3,indictronq,resnonpen,resL,resU,ntU,nb_gl
     use tailles
     use comongroup
     use residusM
@@ -330,14 +330,14 @@
         do ig=1,ng
             auxig = ig
             choix = 1
-            call gaulagJ_intcens(int,choix)
+            call gaulagJ_intcens(int,choix,nb_gl)
             integrale1(ig) = int
 !             if (integrale1(ig).eq.0.d0) then
 !                 integrale1(ig) = 1.d-300
 !             endif
             if (indictronq.eq.1) then
                 choix = 2
-                call gaulagJ_intcens(int,choix)
+                call gaulagJ_intcens(int,choix,nb_gl)
                 integrale2(ig) = int
 !                 if (integrale2(ig).eq.0.d0) then
 !                     integrale2(ig) = 1.d0
