@@ -8,7 +8,7 @@
     use comon,only:etaR,etaD,betaR,betaD, &
     t0,t1,t0dc,t1dc,c,cdc,nsujet,nva,nva1,nva2,nst, &
     effet,stra,ve,vedc,ng,g,nig,AG,indic_ALPHA,ALPHA,sig2, &
-    auxig,aux1,aux2,res1,res3,kkapa,res5,indictronq
+    auxig,aux1,aux2,res1,res3,kkapa,res5,indictronq,nb_gh
     use residusM
     use comongroup
 
@@ -150,16 +150,16 @@
         do ig=1,ng
             auxig = ig
             choix = 1
-            call gauherS(int,choix)
+            call gauherS(int,choix,nb_gh)
             integrale1(ig) = int
             if (AG.eq.1) then
                 choix = 3
-                call gauherS(int,choix)
+                call gauherS(int,choix,nb_gh)
                 integrale3(ig) = int
             endif
             if (indictronq.eq.1) then
                 choix = 2
-                call gauherS(int,choix)
+                call gauherS(int,choix,nb_gh)
                 integrale2(ig) = int
             endif
         end do
@@ -273,7 +273,7 @@
         do ig=1,ng
             auxig = ig
             choix = 3
-            call gauherJ(int,choix)
+            call gauherJ(int,choix,nb_gh)
             integrale3(ig) = int
         end do
 !************* FIN INTEGRALES ************************
