@@ -37,7 +37,8 @@
     integer, dimension(4), intent(in)::indice_esti
     integer::maxit0,mt1,mt2,mt11,mt12,nnodes,aaa,control !nn,npinit,nvatmp
     integer,dimension(4),intent(in)::mtaille
-    integer,intent(in)::nsujet0,ng0,nz0,nva10,nva20,lignedc0,ag0,ntrials0,nst0
+    integer,intent(in)::nsujet0,ng0,nz0,nva10,nva20,lignedc0,ag0,ntrials0,nst0 
+    integer::nst02
     integer,intent(in),dimension(ntrials0)::trials
     double precision,dimension(nz0+6),intent(out)::ziOut
     integer::np,equidistant
@@ -69,7 +70,7 @@
     integer,intent(in)::noVar1,noVar2,intcens0,param_weibull0 !param_weibull! parametrisation de la weibull utilisee: 0= parametrisation par defaut dans le programme de Virginie, 1= parametrisation
     !                                                         a l'aide de la fonction de weibull donnee dans le cours de Pierre
     integer,intent(out)::cpt,cpt_dc,ier,ni
-    integer::groupe,ij,kk,j,k,nz,n,ii,iii,iii2,cptstr1,cptstr2   & !code
+    integer::groupe,ij,kk,j,k,nz,n,iii,iii2,cptstr1,cptstr2   & !code
     ,i,ic,icdc,istop,cptni,cptni1,cptni2,nb_echec,nb_echecor,id,cptbiais &
     ,cptauxdc,p !rang,erreur
     double precision::tt0,tt0dc,tt1,tt1dc,h,hdc,res,min,mindc,max_, &
@@ -122,7 +123,7 @@
                                                  ! le septieme indique le nombre d'effet aleatoire dans le cas de la quadrature adaptative
                                                  ! et le huitieme le type de modele a estimer (0=joint surrogate classique,1=joint surrogate complet)
     double precision,dimension(ng0,nsim_nodes(7)+1+nsim_nodes(7) + (nsim_nodes(7)*(nsim_nodes(7)-1))/2),intent(in):: paGH ! parametre pour l'adaptative: en ligne les individus, en colone on a respectivement: les ui_cham,racine carree du determinant de l'inverse de la cholesky,variance des ui_chap,les covariances estimees des fragilites pour chaque individu, sachant que la matrice de variances covariance est bien la cholesky
-
+    double precision,dimension(ng0,nsim_nodes(7)+1+nsim_nodes(7) + (nsim_nodes(7)*(nsim_nodes(7)-1))/2):: paGH2
     integer, dimension(ntrials0,2),intent(in)::nigs0,cdcs0
     integer, dimension(nsujet0),intent(in)::pourtrial0
     double precision::bi,bs,wres
@@ -136,7 +137,10 @@
     !double precision,dimension(1)::knots
     !double precision, dimension(2)::boundaryknotsurro
     !double precision, dimension(nknots)::innerknotsurro
-
+    if(.false.) then 
+        nst02 = nst0 
+        paGH2 = pagh 
+    end if 
     param_weibull=param_weibull0
     estim_wij_chap=0
     control_affichage = 0
@@ -966,7 +970,7 @@
 
     if(adaptative .and. estim_wij_chap.eq.0)then
         nb0=nsim_nodes(7)
-        nb_ree = nb0 + (nb0*(nb0-1))/2.d0 ! les variances + covariances estimes de la cholesky
+        nb_ree = Int(nb0 + (nb0*(nb0-1))/2.d0) ! les variances + covariances estimes de la cholesky
         ! Parametres pour GH pseudo-adaptative
         allocate(ui_chap(ng0,1),invBi_cholDet(ng0),invBi_chol(ng0,nb_ree),invBi_cholDet_Essai(ntrials))
         allocate(invBi_chol_Essai(ntrials*9),invBi_chol_Individuel(ng0),ui_chap_Essai(ntrials,3))
