@@ -1051,7 +1051,7 @@
         double precision function  func1pred_bivGH1(frail1)
         ! calcul de l integrant (numerateur de la fonction de prediction)
         use comon,only:etaydc,sigmae,s_cag_id,&
-                s_cag,ut,link,npp !nva3,vey,utt,etaydc2,netadc
+                s_cag,ut,link,npp,nb1 !nva3,vey,utt,etaydc2,netadc
         use donnees_indiv,only:nmescur,mu,z2,ycurrent,b1!,it_cur,x2cur,z1cur
         use prediction
         use optim
@@ -1067,15 +1067,15 @@
         integer :: k
         double precision::yscalar
         double precision,dimension(:),allocatable::mu1
-        double precision,dimension(:),allocatable::frail ! /* ajout scl 10/04/2020 pour correction Rank mismatch */
+        !double precision,dimension(:),allocatable::frail ! /* ajout scl 10/04/2020 pour correction Rank mismatch */
+        double precision,dimension(nb1)::frail
         logical :: upper
         double precision,external::survdcCM_pred
         double precision :: resultdc,abserr,resabs,resasc
         double precision,parameter::pi=3.141592653589793d0
         
 		! =========== ajout scl 10/04/2020 pour correction Rank mismatch ========
-		allocate(frail(1))
-		frail(1) = frail1
+        frail(1) = frail1
 		! =========== Fin ajout scl ================
 		
         upper = .false.
@@ -1129,8 +1129,8 @@
                 *1/dsqrt(ut(1,1)*2.d0*pi)
         end if
         
-        deallocate(mu1, frail)
-
+       !deallocate(mu1, frail)
+        deallocate(mu1)
         return
     
         end function func1pred_bivGH1
